@@ -1,6 +1,5 @@
 use core::fmt::Debug;
 
-use clear_on_drop::clear::Clear;
 use curve25519_dalek::constants;
 use curve25519_dalek::ristretto::{CompressedRistretto, RistrettoPoint};
 use curve25519_dalek::scalar::Scalar;
@@ -10,6 +9,7 @@ use hmac::digest::generic_array::GenericArray;
 use hmac::{Mac, NewMac};
 use rand::{CryptoRng, Rng};
 use subtle::{Choice, ConstantTimeEq};
+use zeroize::Zeroize;
 
 use crate::errors::{InternalError, TokenError};
 
@@ -81,7 +81,7 @@ impl TokenPreimage {
         }
 
         let mut bits: [u8; TOKEN_PREIMAGE_LENGTH] = [0u8; TOKEN_PREIMAGE_LENGTH];
-        bits.copy_from_slice(&bytes);
+        bits.copy_from_slice(bytes);
         Ok(TokenPreimage(bits))
     }
 }
@@ -102,7 +102,7 @@ pub struct Token {
 /// Overwrite the token blinding factor with null when it goes out of scope.
 impl Drop for Token {
     fn drop(&mut self) {
-        self.r.clear();
+        self.r.zeroize();
     }
 }
 
@@ -134,7 +134,7 @@ impl Token {
         let mut hash = D::default();
         let mut seed = [0u8; 64];
         hash.update(bytes);
-        seed.copy_from_slice(&hash.finalize().as_slice());
+        seed.copy_from_slice(hash.finalize().as_slice());
 
         Token {
             t: TokenPreimage(seed),
@@ -310,7 +310,7 @@ impl_serde!(SigningKey);
 /// Overwrite signing key with null when it goes out of scope.
 impl Drop for SigningKey {
     fn drop(&mut self) {
-        self.k.clear();
+        self.k.zeroize();
     }
 }
 
@@ -455,7 +455,7 @@ impl UnblindedToken {
 
         let output = hash.finalize();
         let mut output_bytes = [0u8; 64];
-        output_bytes.copy_from_slice(&output.as_slice());
+        output_bytes.copy_from_slice(output.as_slice());
 
         VerificationKey(output_bytes)
     }
